@@ -11,7 +11,7 @@ import warnings
 
 
 __all__ = ["APIError", "Connection"]
-__version__ = '1.4.4'
+__version__ = '1.5.0'
 
 logger = logging.getLogger('scrapinghub')
 
@@ -20,7 +20,7 @@ class Connection(object):
     """Main class to access Scrapinghub API.
     """
 
-    DEFAULT_ENDPOINT = 'http://dash.scrapinghub.com/api/'
+    DEFAULT_ENDPOINT = 'https://dash.scrapinghub.com/api/'
 
     API_METHODS = {
         'addversion': 'scrapyd/addversion',
